@@ -39,7 +39,7 @@ class Exceptions:
 
 class WorkMailMessageFlowClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -48,8 +48,8 @@ class WorkMailMessageFlowClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def generate_presigned_url(
@@ -60,20 +60,20 @@ class WorkMailMessageFlowClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_raw_message_content(self, messageId: str) -> GetRawMessageContentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
-        [Show boto3-stubs documentation](./client.md#get-raw-message-content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.get_raw_message_content)
+        [Show boto3-stubs documentation](./client.md#get_raw_message_content)
         """
 
     def put_raw_message_content(
         self, messageId: str, content: RawMessageContentTypeDef
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.put_raw_message_content)
-        [Show boto3-stubs documentation](./client.md#put-raw-message-content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/workmailmessageflow.html#WorkMailMessageFlow.Client.put_raw_message_content)
+        [Show boto3-stubs documentation](./client.md#put_raw_message_content)
         """
